@@ -32,20 +32,21 @@ import pyworkflow.utils as pwutils
 from .constants import *
 
 
-__version__ = '3.1.0'
+__version__ = '3.1.1'
 _references = ['Zheng2017']
 
 
 class Plugin(pwem.Plugin):
     _homeVar = MOTIONCOR2_HOME
     _pathVars = [MOTIONCOR2_HOME]
-    _supportedVersions = ['1.2.6', '1.3.0', '1.3.1', '1.3.2', '1.4.0']
+    _supportedVersions = ['1.2.6', '1.3.0', '1.3.1',
+                          '1.3.2', '1.4.0', '1.4.2']
     _url = "https://github.com/scipion-em/scipion-em-motioncorr"
 
     @classmethod
     def _defineVariables(cls):
-        cls._defineEmVar(MOTIONCOR2_HOME, 'motioncor2-1.4.0')
-        cls._defineVar(MOTIONCOR2_BIN, 'MotionCor2_1.4.0_Cuda101')
+        cls._defineEmVar(MOTIONCOR2_HOME, 'motioncor2-1.4.2')
+        cls._defineVar(MOTIONCOR2_BIN, 'MotionCor2_1.4.2_Cuda101-02-15-2020')
         cls._defineVar(MOTIONCOR2_CUDA_LIB, pwem.Config.CUDA_LIB)
 
     @classmethod
@@ -78,5 +79,8 @@ class Plugin(pwem.Plugin):
                        tar='motioncor2-1.3.2.tgz')
 
         env.addPackage('motioncor2', version='1.4.0',
-                       tar='motioncor2-1.4.0.tgz',
+                       tar='motioncor2-1.4.0.tgz')
+
+        env.addPackage('motioncor2', version='1.4.2',
+                       tar='motioncor2-1.4.2.tgz',
                        default=True)
